@@ -1,4 +1,4 @@
-use crate::Input;
+use crate::input::Input;
 
 pub fn solve(input: &mut Input) -> Result<u64, String> {
     let words = input.text.split(' ').collect::<Vec<_>>();
